# cooltools

[![Build Status](https://travis-ci.org/open2c/cooltools.svg?branch=master)](https://travis-ci.org/open2c/cooltools)
[![Documentation Status](https://readthedocs.org/projects/cooltools/badge/?version=latest)](https://cooltools.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/82413481.svg)](https://zenodo.org/badge/latestdoi/82413481)

The tools for your .cool's

Documentation can be found here https://cooltools.readthedocs.io/en/latest/

Our contributing guide can be found [here](https://github.com/open2c/cooltools/blob/master/CONTRIBUTING.md).

## Requirements

The following are required before installing cooltools:

* Python 3.4+
* `numpy`
* `cython`

## Installation

```sh
pip install cooltools
```
